==> choices-2.0.4.tar.gz: choices/src/ChoicesCallbacks.php <==
<?php

namespace Drupal\choices;

use Drupal\choices\Form\ConfigForm;
use Drupal\Core\Security\TrustedCallbackInterface;

/**
 * Provides a Choices.js element callback.
 */
class ChoicesCallbacks implements TrustedCallbackInterface {

  /**
   * {@inheritdoc}
   */
  public static function trustedCallbacks() {
    return ['preRender'];
  }

  /**
   * Pre-render handler for select elements.
   */
  public static function preRender($element) {
    $attached = &$element['#attached'];
    $attached['drupalSettings']['choices'] = [];
    // Load Choices.js if applicable.
    $dropdown_type = \Drupal::config('choices.settings')->get('dropdown_type');
    if (static::isApplicable() && ($dropdown_type === ConfigForm::CHOICES_ALL || ($dropdown_type === ConfigForm::CHOICES_MULTIPLE && $element['#multiple'] === TRUE) || ($dropdown_type === ConfigForm::CHOICES_SINGLE && $element['#multiple'] === FALSE))) {
      $cssSelector = \Drupal::config('choices.settings')->get('css_selector');
      $configurationOptions = \Drupal::config('choices.settings')->get('configuration_options');
      $attached['library'][] = 'choices/choices';
      $attached['drupalSettings']['choices']['cssSelector'] = explode("\n", $cssSelector);
      $attached['drupalSettings']['choices']['configurationOptions'] = $configurationOptions;
    }
    return $element;
  }

  /**
   * {@inheritdoc}
   */
  protected static function isApplicable() {
    $config = \Drupal::config('choices.settings');
    if ($config->get('include') === ConfigForm::CHOICES_INCLUDE_EVERYWHERE) {
      return TRUE;
    }

    $theme = \Drupal::theme()->getActiveTheme()->getName();
    $admin_theme = \Drupal::config('system.theme')->get('admin');
    switch ($config->get('include')) {
      case ConfigForm::CHOICES_INCLUDE_ADMIN:
        return $theme === $admin_theme;

      case ConfigForm::CHOICES_INCLUDE_NO_ADMIN:
        return $theme !== $admin_theme;

      case ConfigForm::CHOICES_INCLUDE_EVERYWHERE:
      default:
        return TRUE;
    }
  }

}

==> choices-2.0.5.tar.gz: choices/src/ChoicesCallbacks.php <==
<?php

namespace Drupal\choices;

use Drupal\choices\Form\ConfigForm;
use Drupal\Core\Security\TrustedCallbackInterface;

/**
 * Provides a Choices.js element callback.
 */
class ChoicesCallbacks implements TrustedCallbackInterface {

  /**
   * {@inheritdoc}
   */
  public static function trustedCallbacks() {
    return ['preRender'];
  }

  /**
   * Pre-render handler for select elements.
   */
  public static function preRender($element) {
    $attached = &$element['#attached'];
    $attached['drupalSettings']['choices'] = [];
    // Load Choices.js if applicable.
    if (static::isApplicable()) {
      $cssSelector = \Drupal::config('choices.settings')->get('css_selector');
      $configurationOptions = \Drupal::config('choices.settings')->get('configuration_options');
      $attached['library'][] = 'choices/choices';
      // Replace multiple spaces and newlines with a comma and single space:
      $attached['drupalSettings']['choices']['cssSelector'] = trim(preg_replace('/\s\s+/', ', ', $cssSelector));
      $attached['drupalSettings']['choices']['configurationOptions'] = $configurationOptions;
    }
    return $element;
  }

  /**
   * {@inheritdoc}
   */
  protected static function isApplicable() {
    $include = \Drupal::config('choices.settings')->get('include');
    if ($include === ConfigForm::CHOICES_INCLUDE_EVERYWHERE) {
      return TRUE;
    }

    $isAdminRoute = \Drupal::service('router.admin_context')->isAdminRoute();
    switch ($include) {
      case ConfigForm::CHOICES_INCLUDE_ADMIN:
        return $isAdminRoute;

      case ConfigForm::CHOICES_INCLUDE_NO_ADMIN:
        return !$isAdminRoute;

      default:
        return TRUE;
    }
  }

}
